@@ -28,9 +28,10 @@
 
 G_BEGIN_DECLS
 
-void gdict_show_print_dialog (GtkWindow   *parent,
-			      const gchar *title,
-			      GdictDefbox *defbox);
+void gdict_show_print_preview (GtkWindow   *parent,
+                               GdictDefbox *defbox);
+void gdict_show_print_dialog  (GtkWindow   *parent,
+			       GdictDefbox *defbox);
 
 G_END_DECLS
 
